CITY_INFORMATION = [
    {
        "id": 891,
        "name": "آذربایجان شرقی",
        "slug": "azarbaijan-east-province",
        "children": [
            {
                "id": 891,
                "name": "همهٔ شهرهای آذربایجان شرقی",
                "slug": "azarbaijan-east-province",
                "parent": 891,
                "relativeChildren": [853, 759, 760, 5, 852, 761, 762, 763, 764],
                "isProvince": True,
            },
            {
                "id": 853,
                "name": "آذرشهر",
                "slug": "azarshahr",
                "parent": 891,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 759,
                "name": "اهر",
                "slug": "ahar",
                "parent": 891,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 760,
                "name": "بناب",
                "slug": "bonab",
                "parent": 891,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 5,
                "name": "تبریز",
                "slug": "tabriz",
                "parent": 891,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 852,
                "name": "سراب",
                "slug": "sarab",
                "parent": 891,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 761,
                "name": "سهند",
                "slug": "sahand",
                "parent": 891,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 762,
                "name": "مراغه",
                "slug": "maragheh",
                "parent": 891,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 763,
                "name": "مرند",
                "slug": "marand",
                "parent": 891,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 764,
                "name": "میانه",
                "slug": "mianeh",
                "parent": 891,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 881,
        "name": "آذربایجان غربی",
        "slug": "azerbaijan-west-province",
        "children": [
            {
                "id": 881,
                "name": "همهٔ شهرهای آذربایجان غربی",
                "slug": "azerbaijan-west-province",
                "parent": 881,
                "relativeChildren": [
                    10,
                    859,
                    765,
                    766,
                    767,
                    857,
                    768,
                    858,
                    856,
                    769,
                    792,
                    770,
                ],
                "isProvince": True,
            },
            {
                "id": 10,
                "name": "ارومیه",
                "slug": "urmia",
                "parent": 881,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 859,
                "name": "اشنویه",
                "slug": "oshnavieh",
                "parent": 881,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 765,
                "name": "بوکان",
                "slug": "bukan",
                "parent": 881,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 766,
                "name": "پیرانشهر",
                "slug": "piranshahr",
                "parent": 881,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 767,
                "name": "خوی",
                "slug": "khoy",
                "parent": 881,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 857,
                "name": "سردشت",
                "slug": "sardasht",
                "parent": 881,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 768,
                "name": "سلماس",
                "slug": "salmas",
                "parent": 881,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 858,
                "name": "شاهین دژ",
                "slug": "shahin-dej",
                "parent": 881,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 856,
                "name": "ماکو",
                "slug": "maku",
                "parent": 881,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 769,
                "name": "مهاباد",
                "slug": "mahabad",
                "parent": 881,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 792,
                "name": "میاندوآب",
                "slug": "miandoab",
                "parent": 881,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 770,
                "name": "نقده",
                "slug": "naqadeh",
                "parent": 881,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 906,
        "name": "اردبیل",
        "slug": "ardabil-province",
        "children": [
            {
                "id": 906,
                "name": "همهٔ شهرهای اردبیل",
                "slug": "ardabil-province",
                "parent": 906,
                "relativeChildren": [17, 771, 772, 1741, 1743, 773, 1742],
                "isProvince": True,
            },
            {
                "id": 17,
                "name": "اردبیل",
                "slug": "ardabil",
                "parent": 906,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 771,
                "name": "پارس\u200cآباد",
                "slug": "parsabad",
                "parent": 906,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 772,
                "name": "خلخال",
                "slug": "khalkhal",
                "parent": 906,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1741,
                "name": "سرعین",
                "slug": "sarein",
                "parent": 906,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1743,
                "name": "گرمی",
                "slug": "germi",
                "parent": 906,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 773,
                "name": "مشکین\u200cشهر",
                "slug": "meshgin-shahr",
                "parent": 906,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1742,
                "name": "نمین",
                "slug": "namin",
                "parent": 906,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 890,
        "name": "اصفهان",
        "slug": "isfahan-province",
        "children": [
            {
                "id": 890,
                "name": "همهٔ شهرهای اصفهان",
                "slug": "isfahan-province",
                "parent": 890,
                "relativeChildren": [
                    1737,
                    1723,
                    4,
                    1747,
                    1727,
                    1750,
                    1724,
                    1725,
                    1744,
                    849,
                    1745,
                    1746,
                    30,
                    848,
                    1749,
                    1748,
                    31,
                ],
                "isProvince": True,
            },
            {
                "id": 1737,
                "name": "آران و بیدگل",
                "slug": "aran-va-bidgol",
                "parent": 890,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1723,
                "name": "ابریشم",
                "slug": "abrisham-isfahan",
                "parent": 890,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 4,
                "name": "اصفهان",
                "slug": "isfahan",
                "parent": 890,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1747,
                "name": "خمینی\u200cشهر",
                "slug": "khomeyni-shahr",
                "parent": 890,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1727,
                "name": "خوانسار",
                "slug": "khansar",
                "parent": 890,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1750,
                "name": "خور",
                "slug": "khour",
                "parent": 890,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1724,
                "name": "داران",
                "slug": "daran",
                "parent": 890,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1725,
                "name": "سمیرم",
                "slug": "semirom",
                "parent": 890,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1744,
                "name": "شاهین\u200cشهر",
                "slug": "shahin-shahr",
                "parent": 890,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 849,
                "name": "فلاورجان",
                "slug": "falavarjan",
                "parent": 890,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1745,
                "name": "فولادشهر",
                "slug": "foolad-shahr",
                "parent": 890,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1746,
                "name": "قمصر",
                "slug": "ghamsar",
                "parent": 890,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 30,
                "name": "کاشان",
                "slug": "kashan",
                "parent": 890,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 848,
                "name": "گلپایگان",
                "slug": "golpayegan",
                "parent": 890,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1749,
                "name": "لنجان",
                "slug": "lenjan",
                "parent": 890,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1748,
                "name": "مبارکه",
                "slug": "mobarakeh",
                "parent": 890,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 31,
                "name": "نجف\u200cآباد",
                "slug": "najafabad",
                "parent": 890,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 895,
        "name": "البرز",
        "slug": "alborz-province",
        "children": [
            {
                "id": 895,
                "name": "همهٔ شهرهای البرز",
                "slug": "alborz-province",
                "parent": 895,
                "relativeChildren": [
                    1722,
                    1721,
                    1739,
                    1740,
                    850,
                    1751,
                    2,
                    1738,
                    1720,
                    1753,
                    1752,
                    774,
                    1754,
                ],
                "isProvince": True,
            },
            {
                "id": 1722,
                "name": "آسارا",
                "slug": "asara",
                "parent": 895,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1721,
                "name": "اشتهارد",
                "slug": "eshtehard",
                "parent": 895,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1739,
                "name": "تنکمان",
                "slug": "tankaman",
                "parent": 895,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1740,
                "name": "چهارباغ",
                "slug": "charbagh-alborz",
                "parent": 895,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 850,
                "name": "طالقان",
                "slug": "taleqan",
                "parent": 895,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1751,
                "name": "فردیس",
                "slug": "fardis",
                "parent": 895,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 2,
                "name": "کرج",
                "slug": "karaj",
                "parent": 895,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1738,
                "name": "کوهسار",
                "slug": "koohsar",
                "parent": 895,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1720,
                "name": "گرمدره",
                "slug": "garmdareh",
                "parent": 895,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1753,
                "name": "ماهدشت",
                "slug": "mahdasht",
                "parent": 895,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1752,
                "name": "محمدشهر",
                "slug": "mohammad-shahr",
                "parent": 895,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 774,
                "name": "نظرآباد",
                "slug": "nazarabad",
                "parent": 895,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1754,
                "name": "هشتگرد",
                "slug": "hashtgerd",
                "parent": 895,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 888,
        "name": "ایلام",
        "slug": "ilam-province",
        "children": [
            {
                "id": 888,
                "name": "همهٔ شهرهای ایلام",
                "slug": "ilam-province",
                "parent": 888,
                "relativeChildren": [775, 32, 776, 777, 1823],
                "isProvince": True,
            },
            {
                "id": 775,
                "name": "آبدانان",
                "slug": "abdanan",
                "parent": 888,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 32,
                "name": "ایلام",
                "slug": "ilam",
                "parent": 888,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 776,
                "name": "ایوان",
                "slug": "eyvan",
                "parent": 888,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 777,
                "name": "دهلران",
                "slug": "dehloran",
                "parent": 888,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1823,
                "name": "مهران",
                "slug": "mehran",
                "parent": 888,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 900,
        "name": "بوشهر",
        "slug": "bushehr-province",
        "children": [
            {
                "id": 900,
                "name": "همهٔ شهرهای بوشهر",
                "slug": "bushehr-province",
                "parent": 900,
                "relativeChildren": [778, 1756, 779, 780, 25, 1757, 1755],
                "isProvince": True,
            },
            {
                "id": 778,
                "name": "برازجان",
                "slug": "borazjan",
                "parent": 900,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1756,
                "name": "بندر دیر",
                "slug": "dayyer",
                "parent": 900,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 779,
                "name": "بندر کنگان",
                "slug": "bandar-kangan",
                "parent": 900,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 780,
                "name": "بندر گناوه",
                "slug": "bandar-ganaveh",
                "parent": 900,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 25,
                "name": "بوشهر",
                "slug": "bushehr",
                "parent": 900,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1757,
                "name": "جم",
                "slug": "jam",
                "parent": 900,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1755,
                "name": "خورموج",
                "slug": "khormoj",
                "parent": 900,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 904,
        "name": "تهران",
        "slug": "tehran-province",
        "children": [
            {
                "id": 904,
                "name": "همهٔ شهرهای تهران",
                "slug": "tehran-province",
                "parent": 904,
                "relativeChildren": [
                    1709,
                    1715,
                    1714,
                    29,
                    1764,
                    1707,
                    1768,
                    1760,
                    1767,
                    1766,
                    781,
                    1,
                    1718,
                    782,
                    783,
                    1765,
                    1769,
                    1763,
                    1713,
                    1717,
                    1759,
                    1712,
                    1710,
                    1716,
                    1772,
                    1770,
                    1758,
                    1761,
                    1708,
                    1719,
                    1706,
                    1771,
                    784,
                    1711,
                    1762,
                ],
                "isProvince": True,
            },
            {
                "id": 1709,
                "name": "آبسرد",
                "slug": "absard",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1715,
                "name": "آبعلی",
                "slug": "abali",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1714,
                "name": "ارجمند",
                "slug": "arjmand",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 29,
                "name": "اسلام\u200cشهر",
                "slug": "eslamshahr",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1764,
                "name": "اندیشه",
                "slug": "andisheh-new-town",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1707,
                "name": "باقرشهر",
                "slug": "baghershahr",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1768,
                "name": "بومهن",
                "slug": "bumehen",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1760,
                "name": "پاکدشت",
                "slug": "pakdasht",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1767,
                "name": "پردیس",
                "slug": "pardis",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1766,
                "name": "پرند",
                "slug": "parand",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 781,
                "name": "پیشوا",
                "slug": "pishva",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1,
                "name": "تهران",
                "slug": "tehran",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1718,
                "name": "جوادآباد",
                "slug": "javadabad",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 782,
                "name": "چهاردانگه",
                "slug": "chahar-dangeh",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 783,
                "name": "دماوند",
                "slug": "damavand",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1765,
                "name": "رباط\u200cکریم",
                "slug": "robat-karim",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1769,
                "name": "رودهن",
                "slug": "rudehen",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1763,
                "name": "ری",
                "slug": "shahr-e-rey",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1713,
                "name": "شاهدشهر",
                "slug": "shahedshahr",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1717,
                "name": "شمشک",
                "slug": "shemshak",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1759,
                "name": "شهریار",
                "slug": "shahriar",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1712,
                "name": "صباشهر",
                "slug": "sabashahr",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1710,
                "name": "صفادشت",
                "slug": "safadasht-industrial-city",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1716,
                "name": "فردوسیه",
                "slug": "ferdosiye",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1772,
                "name": "فشم",
                "slug": "fasham",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1770,
                "name": "فیروزکوه",
                "slug": "firuzkooh",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1758,
                "name": "قدس",
                "slug": "qods",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1761,
                "name": "قرچک",
                "slug": "qarchak",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1708,
                "name": "کهریزک",
                "slug": "kahrizak",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1719,
                "name": "کیلان",
                "slug": "kilan",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1706,
                "name": "گلستان",
                "slug": "golestan-baharestan",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1771,
                "name": "لواسان",
                "slug": "lavasan",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 784,
                "name": "نسیم\u200cشهر",
                "slug": "nasimshahr",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1711,
                "name": "وحیدیه",
                "slug": "vahidieh",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1762,
                "name": "ورامین",
                "slug": "varamin",
                "parent": 904,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 903,
        "name": "چهارمحال و بختیاری",
        "slug": "chahar-mahaal-and-bakhtiari-province",
        "children": [
            {
                "id": 903,
                "name": "همهٔ شهرهای چهارمحال و بختیاری",
                "slug": "chahar-mahaal-and-bakhtiari-province",
                "parent": 903,
                "relativeChildren": [785, 1833, 36, 786, 787],
                "isProvince": True,
            },
            {
                "id": 785,
                "name": "بروجن",
                "slug": "boroujen",
                "parent": 903,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1833,
                "name": "سامان",
                "slug": "saman",
                "parent": 903,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 36,
                "name": "شهرکرد",
                "slug": "shahrekord",
                "parent": 903,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 786,
                "name": "فرخ\u200cشهر",
                "slug": "farrokhshahr",
                "parent": 903,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 787,
                "name": "لردگان",
                "slug": "lordegan",
                "parent": 903,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 876,
        "name": "خراسان جنوبی",
        "slug": "khorasan-south-province",
        "children": [
            {
                "id": 876,
                "name": "همهٔ شهرهای خراسان جنوبی",
                "slug": "khorasan-south-province",
                "parent": 876,
                "relativeChildren": [34, 788, 789, 790],
                "isProvince": True,
            },
            {
                "id": 34,
                "name": "بیرجند",
                "slug": "birjand",
                "parent": 876,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 788,
                "name": "طبس",
                "slug": "tabas",
                "parent": 876,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 789,
                "name": "فردوس",
                "slug": "ferdows",
                "parent": 876,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 790,
                "name": "قاين",
                "slug": "ghayen",
                "parent": 876,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 880,
        "name": "خراسان رضوی",
        "slug": "khorasan-razavi-province",
        "children": [
            {
                "id": 880,
                "name": "همهٔ شهرهای خراسان رضوی",
                "slug": "khorasan-razavi-province",
                "parent": 880,
                "relativeChildren": [
                    1735,
                    1729,
                    791,
                    1776,
                    1732,
                    1736,
                    316,
                    1775,
                    1774,
                    1733,
                    1777,
                    1773,
                    847,
                    3,
                    1778,
                    318,
                ],
                "isProvince": True,
            },
            {
                "id": 1735,
                "name": "بردسکن",
                "slug": "bardaskan",
                "parent": 880,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1729,
                "name": "تایباد",
                "slug": "taybad",
                "parent": 880,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 791,
                "name": "تربت جام",
                "slug": "torbat-jam",
                "parent": 880,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1776,
                "name": "تربت\u200cحیدریه",
                "slug": "torbat-heydariyeh",
                "parent": 880,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1732,
                "name": "چناران",
                "slug": "chenaran",
                "parent": 880,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1736,
                "name": "خواف",
                "slug": "khaf",
                "parent": 880,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 316,
                "name": "سبزوار",
                "slug": "sabzevar",
                "parent": 880,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1775,
                "name": "شاندیز",
                "slug": "shandiz",
                "parent": 880,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1774,
                "name": "طرقبه",
                "slug": "torghabeh",
                "parent": 880,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1733,
                "name": "قاسم\u200cآباد (خواف)",
                "slug": "qasemabad-khaf",
                "parent": 880,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1777,
                "name": "قوچان",
                "slug": "quchan",
                "parent": 880,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1773,
                "name": "گلبهار",
                "slug": "golbahar",
                "parent": 880,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 847,
                "name": "گناباد",
                "slug": "gonabad",
                "parent": 880,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 3,
                "name": "مشهد",
                "slug": "mashhad",
                "parent": 880,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1778,
                "name": "ملک\u200cآباد",
                "slug": "molkabad",
                "parent": 880,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 318,
                "name": "نیشابور",
                "slug": "neyshabur",
                "parent": 880,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 896,
        "name": "خراسان شمالی",
        "slug": "khorasan-north-province",
        "children": [
            {
                "id": 896,
                "name": "همهٔ شهرهای خراسان شمالی",
                "slug": "khorasan-north-province",
                "parent": 896,
                "relativeChildren": [793, 794, 39, 795],
                "isProvince": True,
            },
            {
                "id": 793,
                "name": "آشخانه",
                "slug": "ashkhaneh",
                "parent": 896,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 794,
                "name": "اسفراین",
                "slug": "esfarāyen",
                "parent": 896,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 39,
                "name": "بجنورد",
                "slug": "bojnurd",
                "parent": 896,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 795,
                "name": "شیروان",
                "slug": "shirvan",
                "parent": 896,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 902,
        "name": "خوزستان",
        "slug": "khuzestan-province",
        "children": [
            {
                "id": 902,
                "name": "همهٔ شهرهای خوزستان",
                "slug": "khuzestan-province",
                "parent": 902,
                "relativeChildren": [
                    24,
                    1779,
                    796,
                    7,
                    797,
                    798,
                    37,
                    314,
                    1782,
                    1784,
                    799,
                    23,
                    1781,
                    800,
                    756,
                    1780,
                    754,
                    602,
                    317,
                    1783,
                ],
                "isProvince": True,
            },
            {
                "id": 24,
                "name": "آبادان",
                "slug": "abadan",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1779,
                "name": "امیدیه",
                "slug": "omidiyeh",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 796,
                "name": "اندیمشک",
                "slug": "andimeshk",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 7,
                "name": "اهواز",
                "slug": "ahvaz",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 797,
                "name": "ایذه",
                "slug": "izeh",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 798,
                "name": "بندر امام خمینی",
                "slug": "bandar-imam-khomeini",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 37,
                "name": "بندر ماهشهر",
                "slug": "bandar-mahshahr",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 314,
                "name": "بهبهان",
                "slug": "behbahan",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1782,
                "name": "چمران",
                "slug": "chamran-town",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1784,
                "name": "حمیدیه",
                "slug": "hamidiyeh",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 799,
                "name": "خرمشهر",
                "slug": "khorramshahr",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 23,
                "name": "دزفول",
                "slug": "dezful",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1781,
                "name": "رامشیر",
                "slug": "ramshir",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 800,
                "name": "رامهرمز",
                "slug": "ramhormoz",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 756,
                "name": "سوسنگرد",
                "slug": "susangerd",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1780,
                "name": "شادگان",
                "slug": "shadeghan",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 754,
                "name": "شوش",
                "slug": "shush",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 602,
                "name": "شوشتر",
                "slug": "shooshtar",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 317,
                "name": "مسجد سلیمان",
                "slug": "masjed-soleyman",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1783,
                "name": "هندیجان",
                "slug": "hendijan",
                "parent": 902,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 879,
        "name": "زنجان",
        "slug": "zanjan-province",
        "children": [
            {
                "id": 879,
                "name": "همهٔ شهرهای زنجان",
                "slug": "zanjan-province",
                "parent": 879,
                "relativeChildren": [802, 803, 20, 804],
                "isProvince": True,
            },
            {
                "id": 802,
                "name": "ابهر",
                "slug": "abhar",
                "parent": 879,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 803,
                "name": "خرمدره",
                "slug": "khorramdarreh",
                "parent": 879,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 20,
                "name": "زنجان",
                "slug": "zanjan",
                "parent": 879,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 804,
                "name": "قیدار",
                "slug": "qeydar",
                "parent": 879,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 882,
        "name": "سمنان",
        "slug": "semnan-province",
        "children": [
            {
                "id": 882,
                "name": "همهٔ شهرهای سمنان",
                "slug": "semnan-province",
                "parent": 882,
                "relativeChildren": [805, 35, 707, 806],
                "isProvince": True,
            },
            {
                "id": 805,
                "name": "دامغان",
                "slug": "damghan",
                "parent": 882,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 35,
                "name": "سمنان",
                "slug": "semnan",
                "parent": 882,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 707,
                "name": "شاهرود",
                "slug": "shahroud",
                "parent": 882,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 806,
                "name": "گرمسار",
                "slug": "garmsar",
                "parent": 882,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 883,
        "name": "سیستان و بلوچستان",
        "slug": "sistan-and-baluchestan-province",
        "children": [
            {
                "id": 883,
                "name": "همهٔ شهرهای سیستان و بلوچستان",
                "slug": "sistan-and-baluchestan-province",
                "parent": 883,
                "relativeChildren": [807, 747, 1785, 706, 11, 1787, 865, 1786],
                "isProvince": True,
            },
            {
                "id": 807,
                "name": "ایرانشهر",
                "slug": "iranshahr",
                "parent": 883,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 747,
                "name": "چابهار",
                "slug": "chabahar",
                "parent": 883,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1785,
                "name": "خاش",
                "slug": "khash",
                "parent": 883,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 706,
                "name": "زابل",
                "slug": "zabol",
                "parent": 883,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 11,
                "name": "زاهدان",
                "slug": "zahedan",
                "parent": 883,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1787,
                "name": "زهک",
                "slug": "zahak",
                "parent": 883,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 865,
                "name": "سراوان-سیستان و بلوچستان",
                "slug": "saravan",
                "parent": 883,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1786,
                "name": "کنارک",
                "slug": "konarak",
                "parent": 883,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 898,
        "name": "فارس",
        "slug": "fars-province",
        "children": [
            {
                "id": 898,
                "name": "همهٔ شهرهای فارس",
                "slug": "fars-province",
                "parent": 898,
                "relativeChildren": [
                    851,
                    1728,
                    808,
                    1793,
                    809,
                    1791,
                    6,
                    810,
                    1789,
                    1734,
                    1790,
                    1730,
                    1731,
                    1788,
                    1792,
                    1794,
                    1726,
                ],
                "isProvince": True,
            },
            {
                "id": 851,
                "name": "آباده",
                "slug": "abadeh",
                "parent": 898,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1728,
                "name": "اقلید",
                "slug": "eqlid",
                "parent": 898,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 808,
                "name": "جهرم",
                "slug": "jahrom",
                "parent": 898,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1793,
                "name": "خور",
                "slug": "khoour",
                "parent": 898,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 809,
                "name": "داراب",
                "slug": "darab",
                "parent": 898,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1791,
                "name": "زرقان",
                "slug": "zarghan",
                "parent": 898,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 6,
                "name": "شیراز",
                "slug": "shiraz",
                "parent": 898,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 810,
                "name": "صدرا-فارس",
                "slug": "sadra",
                "parent": 898,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1789,
                "name": "فسا",
                "slug": "fasa",
                "parent": 898,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1734,
                "name": "فیروزآباد",
                "slug": "firuzabad",
                "parent": 898,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1790,
                "name": "کازرون",
                "slug": "kazeroon",
                "parent": 898,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1730,
                "name": "لار",
                "slug": "lar",
                "parent": 898,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1731,
                "name": "لامرد",
                "slug": "lamerd",
                "parent": 898,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1788,
                "name": "مرودشت",
                "slug": "marvdasht",
                "parent": 898,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1792,
                "name": "مهر",
                "slug": "mohr",
                "parent": 898,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1794,
                "name": "نورآباد ممسنی",
                "slug": "norabad",
                "parent": 898,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1726,
                "name": "نی\u200cریز",
                "slug": "neyriz",
                "parent": 898,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 878,
        "name": "قزوین",
        "slug": "qazvin-province",
        "children": [
            {
                "id": 878,
                "name": "همهٔ شهرهای قزوین",
                "slug": "qazvin-province",
                "parent": 878,
                "relativeChildren": [869, 1795, 872, 811, 1796, 19, 873],
                "isProvince": True,
            },
            {
                "id": 869,
                "name": "آبیک",
                "slug": "abyek",
                "parent": 878,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1795,
                "name": "اقبالیه",
                "slug": "eqbaliyeh",
                "parent": 878,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 872,
                "name": "الوند",
                "slug": "alvand",
                "parent": 878,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 811,
                "name": "تاکستان",
                "slug": "takestan",
                "parent": 878,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1796,
                "name": "شال",
                "slug": "shal",
                "parent": 878,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 19,
                "name": "قزوین",
                "slug": "qazvin",
                "parent": 878,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 873,
                "name": "محمدیه-قزوین",
                "slug": "mohammadiyeh",
                "parent": 878,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 892,
        "name": "قم",
        "slug": "qom-province",
        "children": [
            {
                "id": 892,
                "name": "همهٔ شهرهای قم",
                "slug": "qom-province",
                "parent": 892,
                "relativeChildren": [8],
                "isProvince": True,
            },
            {
                "id": 8,
                "name": "قم",
                "slug": "qom",
                "parent": 892,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 885,
        "name": "کردستان",
        "slug": "kurdistan-province",
        "children": [
            {
                "id": 885,
                "name": "همهٔ شهرهای کردستان",
                "slug": "kurdistan-province",
                "parent": 885,
                "relativeChildren": [662, 868, 1798, 812, 28, 813, 1797, 814],
                "isProvince": True,
            },
            {
                "id": 662,
                "name": "بانه",
                "slug": "baneh",
                "parent": 885,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 868,
                "name": "بیجار",
                "slug": "bijar",
                "parent": 885,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1798,
                "name": "دهگلان",
                "slug": "dehgolan",
                "parent": 885,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 812,
                "name": "سقز",
                "slug": "saqqez",
                "parent": 885,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 28,
                "name": "سنندج",
                "slug": "sanandaj",
                "parent": 885,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 813,
                "name": "قروه",
                "slug": "qorveh",
                "parent": 885,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1797,
                "name": "کامیاران",
                "slug": "kamyaran",
                "parent": 885,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 814,
                "name": "مریوان",
                "slug": "marivan",
                "parent": 885,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 877,
        "name": "کرمان",
        "slug": "kerman-province",
        "children": [
            {
                "id": 877,
                "name": "همهٔ شهرهای کرمان",
                "slug": "kerman-province",
                "parent": 877,
                "relativeChildren": [
                    1804,
                    1805,
                    1807,
                    815,
                    816,
                    817,
                    867,
                    818,
                    13,
                    1803,
                    1806,
                ],
                "isProvince": True,
            },
            {
                "id": 1804,
                "name": "بافت",
                "slug": "baft",
                "parent": 877,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1805,
                "name": "بردسیر",
                "slug": "bardsir",
                "parent": 877,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1807,
                "name": "بلوک",
                "slug": "boluk",
                "parent": 877,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 815,
                "name": "بم",
                "slug": "bam",
                "parent": 877,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 816,
                "name": "جیرفت",
                "slug": "jiroft",
                "parent": 877,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 817,
                "name": "رفسنجان",
                "slug": "rafsanjan",
                "parent": 877,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 867,
                "name": "زرند",
                "slug": "zarand",
                "parent": 877,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 818,
                "name": "سیرجان",
                "slug": "sirjan",
                "parent": 877,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 13,
                "name": "کرمان",
                "slug": "kerman",
                "parent": 877,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1803,
                "name": "کهنوج",
                "slug": "kahnooj",
                "parent": 877,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1806,
                "name": "ماهان",
                "slug": "mahan",
                "parent": 877,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 905,
        "name": "کرمانشاه",
        "slug": "kermanshah-province",
        "children": [
            {
                "id": 905,
                "name": "همهٔ شهرهای کرمانشاه",
                "slug": "kermanshah-province",
                "parent": 905,
                "relativeChildren": [
                    819,
                    1801,
                    820,
                    854,
                    855,
                    1800,
                    9,
                    821,
                    1802,
                    1799,
                ],
                "isProvince": True,
            },
            {
                "id": 819,
                "name": "اسلام\u200c\u200cآباد غرب",
                "slug": "eslamabad-gharb",
                "parent": 905,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1801,
                "name": "بیستون",
                "slug": "bisotun",
                "parent": 905,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 820,
                "name": "جوانرود",
                "slug": "javanrud",
                "parent": 905,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 854,
                "name": "سرپل ذهاب",
                "slug": "sarpol-zahab",
                "parent": 905,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 855,
                "name": "سنقر",
                "slug": "sonqor",
                "parent": 905,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1800,
                "name": "صحنه",
                "slug": "sahneh",
                "parent": 905,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 9,
                "name": "کرمانشاه",
                "slug": "kermanshah",
                "parent": 905,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 821,
                "name": "کنگاور",
                "slug": "kangavar",
                "parent": 905,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1802,
                "name": "گهواره",
                "slug": "gahvareh",
                "parent": 905,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1799,
                "name": "هرسین",
                "slug": "harsin",
                "parent": 905,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 887,
        "name": "کهگیلویه و بویراحمد",
        "slug": "kohgiluyeh-and-boyer-ahmad-province",
        "children": [
            {
                "id": 887,
                "name": "همهٔ شهرهای کهگیلویه و بویراحمد",
                "slug": "kohgiluyeh-and-boyer-ahmad-province",
                "parent": 887,
                "relativeChildren": [874, 822, 1808, 38],
                "isProvince": True,
            },
            {
                "id": 874,
                "name": "دوگنبدان",
                "slug": "dogonbadan",
                "parent": 887,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 822,
                "name": "دهدشت",
                "slug": "dehdasht",
                "parent": 887,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1808,
                "name": "سی\u200cسخت",
                "slug": "sisakht",
                "parent": 887,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 38,
                "name": "یاسوج",
                "slug": "yasuj",
                "parent": 887,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 897,
        "name": "گلستان",
        "slug": "golestan-province",
        "children": [
            {
                "id": 897,
                "name": "همهٔ شهرهای گلستان",
                "slug": "golestan-province",
                "parent": 897,
                "relativeChildren": [
                    1691,
                    748,
                    751,
                    823,
                    750,
                    1692,
                    1832,
                    21,
                    749,
                    743,
                    1693,
                ],
                "isProvince": True,
            },
            {
                "id": 1691,
                "name": "آزادشهر",
                "slug": "azadshahr-golestan",
                "parent": 897,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 748,
                "name": "آق قلا",
                "slug": "aq-qala",
                "parent": 897,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 751,
                "name": "بندر ترکمن",
                "slug": "bandar-torkaman",
                "parent": 897,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 823,
                "name": "علی\u200cآباد کتول",
                "slug": "aliabad-katul",
                "parent": 897,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 750,
                "name": "کردکوی",
                "slug": "kordkuy",
                "parent": 897,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1692,
                "name": "کلاله",
                "slug": "kalale",
                "parent": 897,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1832,
                "name": "گالیکش",
                "slug": "galikesh",
                "parent": 897,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 21,
                "name": "گرگان",
                "slug": "gorgan",
                "parent": 897,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 749,
                "name": "گمیشان",
                "slug": "gomishan",
                "parent": 897,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 743,
                "name": "گنبد کاووس",
                "slug": "gonbad-kavus",
                "parent": 897,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1693,
                "name": "مینودشت",
                "slug": "minoodasht",
                "parent": 897,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 889,
        "name": "گیلان",
        "slug": "gilan-province",
        "children": [
            {
                "id": 889,
                "name": "همهٔ شهرهای گیلان",
                "slug": "gilan-province",
                "parent": 889,
                "relativeChildren": [
                    824,
                    825,
                    1852,
                    1812,
                    1688,
                    1854,
                    708,
                    1841,
                    829,
                    1855,
                    1850,
                    864,
                    1686,
                    1844,
                    1847,
                    1689,
                    1809,
                    1814,
                    1851,
                    1839,
                    1835,
                    12,
                    1684,
                    1810,
                    1849,
                    826,
                    1683,
                    1811,
                    861,
                    1813,
                    1845,
                    827,
                    860,
                    863,
                    1840,
                    1843,
                    1687,
                    1846,
                    746,
                    1690,
                    828,
                    1836,
                    1842,
                    1837,
                    1848,
                    862,
                    1815,
                    1853,
                    1834,
                ],
                "isProvince": True,
            },
            {
                "id": 824,
                "name": "آستارا",
                "slug": "astara",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 825,
                "name": "آستانه اشرفیه",
                "slug": "astaneh-ashrafiyeh",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1852,
                "name": "احمدسرگوراب",
                "slug": "ahmadsar-gourab",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1812,
                "name": "اسالم",
                "slug": "asalem",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1688,
                "name": "املش",
                "slug": "amlash",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1854,
                "name": "بره\u200cسر",
                "slug": "barah-sar",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 708,
                "name": "بندر انزلی",
                "slug": "bandar-anzali",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1841,
                "name": "پره\u200cسر",
                "slug": "pareh-sar",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 829,
                "name": "تالش",
                "slug": "talesh",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1855,
                "name": "توتکابن",
                "slug": "toutkabon",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1850,
                "name": "جیرنده",
                "slug": "jirandeh",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 864,
                "name": "چابکسر",
                "slug": "chaboksar",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1686,
                "name": "چاف و چمخاله",
                "slug": "chaf-chamkhale",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1844,
                "name": "چوبر",
                "slug": "chobar",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1847,
                "name": "حویق",
                "slug": "haviq",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1689,
                "name": "خشکبیجار",
                "slug": "khoshkbijar",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1809,
                "name": "خمام",
                "slug": "khomam",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1814,
                "name": "دیلمان",
                "slug": "deylaman",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1851,
                "name": "رانکوه",
                "slug": "rankouh",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1839,
                "name": "رحیم\u200cآباد",
                "slug": "rahim-abad",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1835,
                "name": "رستم\u200cآباد",
                "slug": "rostam-abad",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 12,
                "name": "رشت",
                "slug": "rasht",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1684,
                "name": "رضوانشهر",
                "slug": "rezvanshahr",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1810,
                "name": "رودبار",
                "slug": "rudbar",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1849,
                "name": "رودبنه",
                "slug": "roudbaneh",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 826,
                "name": "رودسر",
                "slug": "rudsar",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1683,
                "name": "زیباکنار",
                "slug": "zibakenar",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1811,
                "name": "سنگر",
                "slug": "sangar",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 861,
                "name": "سیاهکل",
                "slug": "siahkal",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1813,
                "name": "شفت",
                "slug": "shaft",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1845,
                "name": "شلمان",
                "slug": "shelman",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 827,
                "name": "صومعه\u200cسرا",
                "slug": "someh-sara",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 860,
                "name": "فومن",
                "slug": "fuman",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 863,
                "name": "کلاچای",
                "slug": "kelachay",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1840,
                "name": "کوچصفهان",
                "slug": "kouchesfahan",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1843,
                "name": "کومله",
                "slug": "koumeleh",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1687,
                "name": "کیاشهر",
                "slug": "kiashahr",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1846,
                "name": "گوراب زرمیخ",
                "slug": "gourab-zarmikh",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 746,
                "name": "لاهیجان",
                "slug": "lahijan",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1690,
                "name": "لشت نشا",
                "slug": "lashtenesha",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 828,
                "name": "لنگرود",
                "slug": "langarud",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1836,
                "name": "لوشان",
                "slug": "loshan",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1842,
                "name": "لولمان",
                "slug": "loulman",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1837,
                "name": "لوندویل",
                "slug": "lavandevil",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1848,
                "name": "لیسار",
                "slug": "lisar",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 862,
                "name": "ماسال",
                "slug": "masal",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1815,
                "name": "ماسوله",
                "slug": "masuleh",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1853,
                "name": "ماکلوان",
                "slug": "makloan",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1834,
                "name": "منجیل",
                "slug": "manjil",
                "parent": 889,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 884,
        "name": "لرستان",
        "slug": "lorestan-province",
        "children": [
            {
                "id": 884,
                "name": "همهٔ شهرهای لرستان",
                "slug": "lorestan-province",
                "parent": 884,
                "relativeChildren": [870, 1816, 830, 26, 1817, 27, 752, 831, 753],
                "isProvince": True,
            },
            {
                "id": 870,
                "name": "ازنا",
                "slug": "azna",
                "parent": 884,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1816,
                "name": "الشتر",
                "slug": "aleshtar",
                "parent": 884,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 830,
                "name": "الیگودرز",
                "slug": "aligudarz",
                "parent": 884,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 26,
                "name": "بروجرد",
                "slug": "borujerd",
                "parent": 884,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1817,
                "name": "پلدختر",
                "slug": "pol-dokhtar",
                "parent": 884,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 27,
                "name": "خرم\u200cآباد",
                "slug": "khorramabad",
                "parent": 884,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 752,
                "name": "دورود",
                "slug": "dorud",
                "parent": 884,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 831,
                "name": "کوهدشت",
                "slug": "kuhdasht",
                "parent": 884,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 753,
                "name": "نورآباد",
                "slug": "nurabad",
                "parent": 884,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 893,
        "name": "مازندران",
        "slug": "mazandaran-province",
        "children": [
            {
                "id": 893,
                "name": "همهٔ شهرهای مازندران",
                "slug": "mazandaran-province",
                "parent": 893,
                "relativeChildren": [
                    1871,
                    663,
                    1703,
                    1701,
                    664,
                    710,
                    1873,
                    832,
                    1865,
                    1702,
                    833,
                    834,
                    835,
                    1694,
                    1861,
                    1868,
                    745,
                    1860,
                    1698,
                    1872,
                    1859,
                    22,
                    1700,
                    1699,
                    1862,
                    1863,
                    1697,
                    1819,
                    836,
                    1875,
                    665,
                    1858,
                    1695,
                    1696,
                    1870,
                    1869,
                    1864,
                    1866,
                    1876,
                    1856,
                    837,
                    1867,
                    1874,
                    1818,
                    838,
                    744,
                    709,
                ],
                "isProvince": True,
            },
            {
                "id": 1871,
                "name": "آلاشت",
                "slug": "aalasht",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 663,
                "name": "آمل",
                "slug": "amol",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1703,
                "name": "امیرکلا",
                "slug": "amirkala",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1701,
                "name": "ایزدشهر",
                "slug": "izadshahr",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 664,
                "name": "بابل",
                "slug": "babol",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 710,
                "name": "بابلسر",
                "slug": "babolsar",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1873,
                "name": "بلده",
                "slug": "baladeh",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 832,
                "name": "بهشهر",
                "slug": "behshahr",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1865,
                "name": "بهنمیر",
                "slug": "bahnamir",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1702,
                "name": "پل سفید",
                "slug": "polsefid",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 833,
                "name": "تنکابن",
                "slug": "tonekabon",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 834,
                "name": "جویبار",
                "slug": "juybar",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 835,
                "name": "چالوس",
                "slug": "chalus",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1694,
                "name": "چمستان",
                "slug": "chamestan",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1861,
                "name": "خلیل شهر",
                "slug": "khalil-shahr",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1868,
                "name": "خوش\u200cرودپی",
                "slug": "khoshroud-pey",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 745,
                "name": "رامسر",
                "slug": "ramsar",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1860,
                "name": "رستمکلا",
                "slug": "rostamkola",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1698,
                "name": "رویان",
                "slug": "royan",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1872,
                "name": "رینه",
                "slug": "reyneh",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1859,
                "name": "زیرآب",
                "slug": "ziraab",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 22,
                "name": "ساری",
                "slug": "sari",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1700,
                "name": "سرخرود",
                "slug": "sorkhrood",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1699,
                "name": "سلمان\u200cشهر",
                "slug": "salman-shahr",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1862,
                "name": "سورک",
                "slug": "sourek",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1863,
                "name": "شیرگاه",
                "slug": "shirgah",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1697,
                "name": "عباس\u200cآباد",
                "slug": "abbasabad-mazandaran",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1819,
                "name": "فرح آباد",
                "slug": "farahabad",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 836,
                "name": "فریدون\u200cکنار",
                "slug": "fereydunkenar",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1875,
                "name": "فریم",
                "slug": "farim",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 665,
                "name": "قائم\u200cشهر",
                "slug": "qaemshahr",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1858,
                "name": "کتالم و سادات شهر",
                "slug": "katalem-sadatshahr",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1695,
                "name": "کلارآباد",
                "slug": "kelarabad",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1696,
                "name": "کلاردشت",
                "slug": "kelarestan",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1870,
                "name": "کوهی\u200cخیل",
                "slug": "kouhi-kheyl",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1869,
                "name": "کیاسر",
                "slug": "kiasar",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1864,
                "name": "کیاکلا",
                "slug": "kiakola",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1866,
                "name": "گتاب",
                "slug": "gatab",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1876,
                "name": "گزنک",
                "slug": "gazanak",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1856,
                "name": "گلوگاه",
                "slug": "galougah-babol",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 837,
                "name": "محمودآباد",
                "slug": "mahmudabad",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1867,
                "name": "مرزن\u200cآباد",
                "slug": "marzan-abad",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1874,
                "name": "مرزیکلا",
                "slug": "marzikola",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1818,
                "name": "نشتارود",
                "slug": "nashtarud",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 838,
                "name": "نکا",
                "slug": "neka",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 744,
                "name": "نور",
                "slug": "nur",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 709,
                "name": "نوشهر",
                "slug": "nowshahr",
                "parent": 893,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 901,
        "name": "مرکزی",
        "slug": "markazi-province",
        "children": [
            {
                "id": 901,
                "name": "همهٔ شهرهای مرکزی",
                "slug": "markazi-province",
                "parent": 901,
                "relativeChildren": [15, 839, 1824, 671, 1825, 840, 1826],
                "isProvince": True,
            },
            {
                "id": 15,
                "name": "اراک",
                "slug": "arak",
                "parent": 901,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 839,
                "name": "خمین",
                "slug": "khomein",
                "parent": 901,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1824,
                "name": "دلیجان",
                "slug": "delijan",
                "parent": 901,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 671,
                "name": "ساوه",
                "slug": "saveh",
                "parent": 901,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1825,
                "name": "شازند",
                "slug": "shazand",
                "parent": 901,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 840,
                "name": "محلات",
                "slug": "mahalat",
                "parent": 901,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1826,
                "name": "مهاجران",
                "slug": "mohajeran",
                "parent": 901,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 894,
        "name": "هرمزگان",
        "slug": "hormozgan-province",
        "children": [
            {
                "id": 894,
                "name": "همهٔ شهرهای هرمزگان",
                "slug": "hormozgan-province",
                "parent": 894,
                "relativeChildren": [18, 1822, 1820, 660, 33, 841, 1821],
                "isProvince": True,
            },
            {
                "id": 18,
                "name": "بندرعباس",
                "slug": "bandar-abbas",
                "parent": 894,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1822,
                "name": "تخت",
                "slug": "takht",
                "parent": 894,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1820,
                "name": "درگهان",
                "slug": "dargahan",
                "parent": 894,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 660,
                "name": "قشم",
                "slug": "qeshm",
                "parent": 894,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 33,
                "name": "کیش",
                "slug": "kish",
                "parent": 894,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 841,
                "name": "میناب",
                "slug": "minab",
                "parent": 894,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1821,
                "name": "هرمز",
                "slug": "hormuz",
                "parent": 894,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 899,
        "name": "همدان",
        "slug": "hamadan-province",
        "children": [
            {
                "id": 899,
                "name": "همهٔ شهرهای همدان",
                "slug": "hamadan-province",
                "parent": 899,
                "relativeChildren": [842, 1828, 866, 1827, 843, 844, 14],
                "isProvince": True,
            },
            {
                "id": 842,
                "name": "اسدآباد",
                "slug": "asadabad",
                "parent": 899,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1828,
                "name": "بهار",
                "slug": "bahar",
                "parent": 899,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 866,
                "name": "تویسرکان",
                "slug": "tuyserkan",
                "parent": 899,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1827,
                "name": "کبودراهنگ",
                "slug": "kabudrahang",
                "parent": 899,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 843,
                "name": "ملایر",
                "slug": "malayer",
                "parent": 899,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 844,
                "name": "نهاوند",
                "slug": "nahavand",
                "parent": 899,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 14,
                "name": "همدان",
                "slug": "hamedan",
                "parent": 899,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
    {
        "id": 886,
        "name": "یزد",
        "slug": "yazd-province",
        "children": [
            {
                "id": 886,
                "name": "همهٔ شهرهای یزد",
                "slug": "yazd-province",
                "parent": 886,
                "relativeChildren": [846, 1829, 1831, 871, 1830, 845, 16],
                "isProvince": True,
            },
            {
                "id": 846,
                "name": "اردکان",
                "slug": "ardakan",
                "parent": 886,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1829,
                "name": "بافق",
                "slug": "bafq",
                "parent": 886,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1831,
                "name": "تفت",
                "slug": "taft",
                "parent": 886,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 871,
                "name": "حمیدیا",
                "slug": "hamidia",
                "parent": 886,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 1830,
                "name": "مهریز",
                "slug": "mehriz",
                "parent": 886,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 845,
                "name": "میبد",
                "slug": "meybod",
                "parent": 886,
                "relativeChildren": None,
                "isProvince": None,
            },
            {
                "id": 16,
                "name": "یزد",
                "slug": "yazd",
                "parent": 886,
                "relativeChildren": None,
                "isProvince": None,
            },
        ],
    },
]

CATEGORIES = {
 'ROOT': '',
 'accessories': 'pet-supplies',
 'accounting-and-finance': 'financial-services',
 'accounting-finance-legal': 'finance-legal-jobs',
 'administration-and-hr': 'administrative-jobs',
 'air-conditioning-fan-coil': 'air-conditioning-fan-coil',
 'animals': 'pets-animals',
 'apartment-rent': 'rent-apartment',
 'apartment-sell': 'buy-apartment',
 'appliance': 'appliance',
 'artificial-flower': 'artificial-flower',
 'audio-video': 'video-audio-device',
 'baby-and-toys': 'child-products',
 'ball-sports': 'ball-sports',
 'barbershop-and-beautysalon': 'barber-shop-equipment',
 'batch': 'wholesale',
 'bathroom-accessories': 'bathroom-accessories',
 'bathrooms': 'bathrooms',
 'beauty-and-haircare': 'beauty-services',
 'bed-pillow-blanket': 'bed-pillow-blanket',
 'bed-service': 'bed-service',
 'bed-sheet': 'bed-sheet',
 'bicycle': 'bike-skate-scooter',
 'birds': 'birds',
 'boat': 'boat',
 'book-student-literature': 'publication',
 'bookcase-shelf': 'bookcase-shelf',
 'buffet-showcases': 'buffet-showcases',
 'building-equipment': 'building-equipment',
 'bus-metro-train': 'travel-ticket',
 'cafe-and-restaurant': 'restaurant-equipment',
 'camera-camcoders': 'camera',
 'camping-outdoor': 'mountaineering-camping',
 'car-and-motor': 'vehicles-services',
 'care-health-beauty': 'health-beauty-jobs',
 'carpet': 'carpet',
 'carpet-moquette': 'carpet-moquette',
 'cars': 'auto',
 'cat': 'cats',
 'catering': 'catering-services',
 'chair-bench': 'chair-bench',
 'chandeliers': 'chandeliers',
 'child-car-seat': 'child-furniture',
 'childrens-clothing-and-shoe': 'child-apparel',
 'childrens-furniture': 'child-stuff',
 'classic': 'classic-car',
 'cleaning': 'cleaning-services',
 'cleaning-supplies': 'cleaning-supplies',
 'clothes-rack': 'clothes-rack',
 'clothing': 'clothing',
 'clothing-and-shoes': 'apparel',
 'coin-stamp': 'stamp-coin-collecting',
 'commercial-rent': 'rent-commercial-property',
 'commercial-sell': 'buy-commercial-property',
 'community': 'social-services',
 'computer-and-it': 'it-computer-jobs',
 'computer-and-mobile': 'technology-services',
 'computers': 'computers',
 'concert': 'concert-ticket',
 'conference-meeting': 'seminars-conference',
 'construction-craft': 'architect-jobs',
 'container-organizers': 'container-organizers',
 'containers': 'containers',
 'cooking-utensils': 'cooking-utensils',
 'crafts': 'crafts',
 'craftsmen': 'craft-skill-services',
 'curtains-table-cover': 'curtains-table-cover',
 'decoration': 'decoration',
 'desk': 'desk',
 'desktops': 'desktop-computer',
 'detergent-tissue': 'detergent-tissue',
 'dining-table': 'dining-table',
 'dishwasher': 'dishwasher',
 'diving-watersports': 'water-sports',
 'dog': 'dogs',
 'drink-maker': 'drink-maker',
 'drums-percussion': 'percussion-instruments',
 'education': 'teaching-jobs',
 'educational': 'educational-book',
 'electronic-devices': 'electronic-devices',
 'event': 'event',
 'events-sports': 'events-sports',
 'fan-ventilator-humidifier': 'fan-ventilator-humidifier',
 'farm-animals': 'farm-animals',
 'figurines': 'figurines',
 'fish': 'fishes',
 'fishing': 'fishing',
 'food-and-drink': 'food-and-drink',
 'food-mill': 'food-mill',
 'for-sale': 'auction',
 'furniture': 'furniture',
 'furniture-wood': 'furniture-wood',
 'game-consoles-and-video-games': 'game-consoles',
 'garden-and-landscaping': 'gardening-services',
 'gift-certificate': 'discount-gift-card',
 'guitar-bass-amplifier': 'guitars',
 'health-beauty': 'beauty-and-personal-care',
 'heavy': 'heavy-car',
 'historical': 'historical-book',
 'historical-objects': 'antique-objects',
 'hobby-collectibles': 'collecting',
 'home-catering': 'home-catering',
 'home-kitchen': 'home-kitchen',
 'home-lighting': 'home-lighting',
 'horses-equestrian': 'horse-riding',
 'house-villa-rent': 'rent-villa',
 'house-villa-sell': 'buy-villa',
 'industrial-machinery': 'industrial-machinery',
 'industrial-technology': 'technical-jobs',
 'industry-agriculture-business-rent': 'rent-industrial-agricultural-property',
 'industry-agriculture-business-sell': 'buy-industrial-agricultural-property',
 'janitorial-cleaning': 'janitorial-jobs',
 'jewelry': 'jewellery',
 'jewelry-and-watches': 'accessories',
 'jobs': 'jobs',
 'juicers': 'juicers',
 'kitchen-utensils': 'kitchen-utensils',
 'lamps': 'lamps',
 'lampshade': 'lampshade',
 'laptops': 'laptop-notebook-macbook',
 'leisure-hobbies': 'entertainment',
 'leisure-hobbies-toys': 'game-and-toys',
 'light': 'car',
 'literary': 'literary-book',
 'lost-and-found': 'missing',
 'lost-animals': 'lost-animals',
 'lost-things': 'lost-objects',
 'lumbar-pillow': 'lumbar-pillow',
 'magazines': 'magazine',
 'mat': 'mat',
 'mattress': 'mattress',
 'media-advertising': 'art-media-jobs',
 'medical-equipment': 'medical-equipment',
 'mirror': 'mirror',
 'mobile-phones': 'mobile-phones',
 'mobile-tablet': 'mobile-tablet',
 'mobile-tablet-accessories': 'mobile-tablet-accessories',
 'modem-and-network-equipment': 'modem-network-equipments',
 'moquette': 'moquette',
 'motorcycles': 'motorcycles',
 'movies-and-music': 'film-music',
 'mp3-player': 'headphone-speaker-microphone',
 'musical-instruments': 'musical-instruments',
 'natural-plants': 'natural-plants',
 'office-decoration': 'office-decoration',
 'office-rent': 'rent-office',
 'office-sell': 'buy-office',
 'offices': 'office-equipment',
 'other-appliances': 'other-appliances',
 'oven-baking-appliances': 'oven-baking-appliances',
 'paintings-picture': 'paintings-picture',
 'partnership': 'contribution-construction',
 'parts-accessories': 'car-accessories',
 'parts-and-accessories': 'computer-parts-accessories',
 'personal': 'personal-goods',
 'personal-toys': 'child-toys',
 'phone': 'telephone',
 'phone-desk': 'phone-desk',
 'piano-keyboard': 'organ-piano-accordion',
 'pictorial-carpet': 'pictorial-carpet',
 'plot-old': 'buy-old-house',
 'pot-kettle': 'pot-kettle',
 'presell': 'pre-sell-home',
 'printer-scaner-copier': 'printer-scanner-fax',
 'range-hood': 'range-hood',
 'real-estate': 'real-estate',
 'real-estate-services': 'real-estate-services',
 'refrigerator-freezer': 'refrigerator-freezer',
 'religious': 'religious-book',
 'rental': 'rental-car',
 'reptile': 'reptiles',
 'research': 'education-research-partner',
 'residential-rent': 'rent-residential',
 'residential-sell': 'buy-residential',
 'rhinestones': 'trinket',
 'rodents-rabbits': 'rodents',
 'rubber-carpet': 'rubber-carpet',
 'rugs-woolen-cloth': 'rugs-woolen-cloth',
 'sales-marketing': 'marketing-jobs',
 'services': 'services',
 'sewing-accessories': 'sewing-accessories',
 'sewing-knitting': 'sewing-knitting',
 'sewing-machine': 'sewing-machine',
 'shoe-rack-drawer': 'shoe-rack-drawer',
 'shoes-belt-bag': 'bag-shoes-belt',
 'shop-and-cash': 'store-equipment',
 'shop-rent': 'rent-store',
 'shop-restaurant': 'service-jobs',
 'shop-sell': 'buy-store',
 'sim-card': 'sim-card',
 'sleep-goods': 'sleep-goods',
 'sport': 'sport-ticket',
 'sport-leisure': 'sport-entertainment',
 'stationery': 'stationery',
 'steam-iron': 'steam-iron',
 'stereo-surround': 'home-audio-system',
 'stoves-heaters-fireplaces': 'stoves-heaters-fireplaces',
 'strollers-and-accessories': 'stroller',
 'suite-apartment': 'rent-temporary-suite-apartment',
 'tablecloths': 'tablecloths',
 'tablet': 'tablet',
 'teaching': 'teaching-services',
 'temporary-rent': 'rent-temporary',
 'theatre-and-cinema': 'theatre-cinema-ticket',
 'ticket': 'ticket',
 'tickets-sports': 'match-sport-ticket',
 'toolbox': 'toolbox',
 'tools-materials-equipment': 'tools-materials-equipment',
 'traditional': 'iranian-instruments',
 'training': 'sport-equipment',
 'transport': 'transport-logistic-services',
 'transportation': 'transport-delivery-jobs',
 'travel-packages': 'tours',
 'tv-projector': 'tv-projector',
 'tv-stand': 'tv-stand',
 'vacuums-cleaner': 'vacuums-cleaner',
 'vehicles': 'vehicles',
 'ventilation-cooling-heating': 'ventilation-cooling-heating',
 'video-dvdplayer': 'dvd-bluray-player',
 'villa': 'rent-temporary-villa',
 'violins': 'violins',
 'volunteers': 'voluntary',
 'wall-clock': 'wall-clock',
 'washing-cleaning': 'washing-cleaning',
 'washing-machines': 'washing-machines',
 'watches': 'watches',
 'water-cooler': 'water-cooler',
 'water-cooler-refinery': 'water-cooler-refinery',
 'water-heater-package-radiator': 'water-heater-package-radiator',
 'wc-accessories': 'wc-accessories',
 'wind': 'wind-instrument',
 'winter-sports': 'winter-sports',
 'work-equipment': 'work-equipment',
 'workspace': 'rent-temporary-workspace',
 'yarn-lights': 'yarn-lights'}


import copy
import requests
import time
from abc import ABC, abstractmethod
from datetime import datetime, timedelta
from .core.info import CITY_INFORMATION, CATEGORIES


class Validator(ABC):
    """
    Abstract base class for all validators
    """

    @abstractmethod
    def validate(self, value):
        """
        Validates the given value and returns
        the validated value or raises an exception
        """
        pass


class SortValidator(Validator):
    @staticmethod
    def validate(sort):
        valid_sorts = ["sort_date", "cheapest", "most_expensive"]
        if sort not in valid_sorts:
            raise ValueError(f"sort must be one of {valid_sorts}")
        return sort


class CategoryValidator(Validator):
    @staticmethod
    def validate(category):
        valid_cats = CATEGORIES
        if category not in valid_cats:
            raise ValueError(f"Invalid category {category}")
        return category


class CitiesValidator(Validator):
    @staticmethod
    def validate(cities):
        if cities == "__all__":
            cities = [
                str(city["id"])
                for province in CITY_INFORMATION
                for city in province["children"]
                if not city["isProvince"]
            ]
        else:
            cities = [str(_id) for _id in cities]
        return cities


class DivarAPI:
    BASE_URL = "https://api.divar.ir/v8/web-search/"
    PARAMS = {
        "page": 1,
        "json_schema": {
            "category": {"value": "ROOT"},
            "sort": {"value": "sort_date"},
            "cities": [],
        },
    }

    @staticmethod
    def build_url(category, cities, sort=None, method="GET", filters={}):
        if method == "GET":
            city = "iran" if len(cities) != 1 else next(
                (child['slug'] for province in CITY_INFORMATION for child in province['children'] if
                 child['id'] == int(cities[0])), None)
            url = DivarAPI.BASE_URL + f"{city}/" + CATEGORIES.get(category)
            url += "?cities=" + "%2C".join(cities)
            if sort:
                url += "&sort=" + sort
            if filters:
                for filter_name, filter_value in filters.items():
                    if isinstance(filter_value, list):
                        filter_value = "%2C".join(filter_value)
                    url += f"&{filter_name}={filter_value}"
        elif method == "POST":
            url = DivarAPI.BASE_URL + "1/" + category
        else:
            raise ValueError('method must be one of "GET", "POST"')
        return url

    @staticmethod
    def build_params(category, sort, cities, last_post_date, filters={}):
        sort = SortValidator.validate(sort)
        category = CategoryValidator.validate(category)
        cities = CitiesValidator.validate(cities)
        params = copy.deepcopy(DivarAPI.PARAMS)
        params["json_schema"]["sort"]["value"] = sort
        params["json_schema"]["cities"] = cities
        params["json_schema"]["category"]["value"] = category
        params["last-post-date"] = last_post_date
        for filter_name, filter_value in filters.items():
                params["json_schema"][filter_name] = {"value": filter_value}
        return params


class DivarParser:
    @staticmethod
    def extract_ads(data):
        ads = []
        for ad in data["web_widgets"]["post_list"]:
            if ad["widget_type"] == "POST_ROW":
                ad = ad["data"]
                ads.append(ad)
        return ads


class DivarClient:
    """
    A class representing a client for interacting with the Divar API.

    Methods:
    - get(url): Sends a GET request to the specified URL and returns the extracted ads and the last post date.
    - post(url, params): Sends a POST request to the specified URL with the given parameters and returns the ads and a flag indicating if it's the last page.
    """

    @staticmethod
    def get(url):
        response = requests.get(url)
        if response.status_code == 200:
            response = response.json()
            return DivarParser.extract_ads(response), response["last_post_date"]
        elif response.status_code == 404:
            return [], -1
        else:
            time.sleep(5)
            return DivarClient.get(url)

    @staticmethod
    def post(url, params):
        while True:
            response = requests.post(url, json=params)
            if response.status_code == 429:
                time.sleep(5)
                continue
            if response.status_code >= 500:
                continue
            break
        data = response.json()
        _is_last_page = "last_post_date" not in data or data["last_post_date"] == -1
        if _is_last_page:
            return [], _is_last_page

        params["page"] += 1
        last_post_date = data["last_post_date"]
        params["last-post-date"] = last_post_date
        ads = DivarParser.extract_ads(data)
        return ads, _is_last_page


class AdFetcher:
    @staticmethod
    def get_ads(
        category,
        sort="sort_date",
        cities="__all__",
        _from=int((datetime.now() - timedelta(days=1)).strftime("%s%f")),
        filters={},
    ):
        """
        Retrieves ads from Divar API based on the specified category, sort order, cities, and other optional parameters.

        Parameters:
        - category (str): The category of ads to retrieve.
        - sort (str, optional): The sort order of the ads. Defaults to 'sort_date'.
        - cities (str, optional): The cities to filter the ads by. Defaults to '__all__'.
        - _from (int, optional): The timestamp indicating the starting point to retrieve ads from. Defaults to 24 hours ago.
        - filters (dict, optional): The filters to apply to the ads. Defaults to {}.

        Returns:
        - ads (list): A list of ads retrieved from the Divar API.
        """
        sort = SortValidator.validate(sort)
        category = CategoryValidator.validate(category)
        cities = CitiesValidator.validate(cities)

        url = DivarAPI.build_url(category, cities, sort, method="GET", filters=filters)
        print(url)
        ads, last_post_date = DivarClient.get(url)
        for ad in ads:
            yield ad

        params = DivarAPI.build_params(category, sort, cities, last_post_date, filters=filters)
        while params["last-post-date"] >= _from:
            url = DivarAPI.build_url(category, cities, sort, method="POST", filters=filters)
            ads, is_last_page = DivarClient.post(url, params)
            for ad in ads:
                yield ad
            if is_last_page:
                break



import asyncio
from aiohttp import ClientSession
from aiohttp.client_exceptions import ClientConnectorError, ServerDisconnectedError



import abc
from typing import Any, Protocol

class PostDetailProvider(Protocol):
    """
    A protocol defining the interface for getting post details.

    This protocol should be implemented by classes that provide the functionality
    to retrieve post details using a token, session, and semaphore.

    Attributes:
        token (str): The authentication token.
        session (ClientSession): The session object for making HTTP requests.
        semaphore (asyncio.Semaphore): The semaphore for controlling concurrent access.

    Returns:
        Any: The post details.

    """

    @abc.abstractmethod
    async def get_detail(self, token: str, session: ClientSession, semaphore: asyncio.Semaphore) -> Any:
        pass
    
class DefaultPostDetailProvider(PostDetailProvider):
    """
    Default implementation of the PostDetailProvider interface.
    Retrieves post details from the Divar API using the provided token.
    """

    BASE_URL = "https://api.divar.ir/v8/posts-v2/web/{token}"
    MAX_RETRY = 3

    async def get_detail(self, token: str, session: ClientSession, semaphore: asyncio.Semaphore) -> Any:
        """
        Retrieves the detail of a post using the given token.

        Args:
            token (str): The token of the post.
            session (ClientSession): The aiohttp ClientSession object for making HTTP requests.
            semaphore (asyncio.Semaphore): The semaphore for limiting concurrent requests.

        Returns:
            Any: The JSON response containing the post detail, or None if the post is not found.

        Raises:
            ClientConnectorError: If there is an error connecting to the server.
            ServerDisconnectedError: If the server disconnects unexpectedly.
        """
        async with semaphore:
            for retry in range(3):
                try:
                    async with session.get(self.BASE_URL.format(token=token)) as response:
                        if response.status == 200:
                            print(f"Get detail of {token}")
                            return await response.json()
                        elif response.status == 404:
                            print(f"Token {token} not found")
                            return None
                        else:
                            print(f"Status code {response.status} for token {token}")
                            await asyncio.sleep(5)
                            return await self.get_detail(token, session, semaphore)
                except ClientConnectorError as e:
                    if retry < self.MAX_RETRY:
                        await asyncio.sleep(5)
                        continue
                    raise e
                except ServerDisconnectedError as e:
                    if retry < self.MAX_RETRY:
                        await asyncio.sleep(10)
                        continue
                    raise e
        
class PostDetailService:
    """
    A service class for retrieving post details.

    Args:
        provider (PostDetailProvider): The provider for retrieving post details. Defaults to DefaultPostDetailProvider().

    Methods:
        get_post_details: Retrieves the details of multiple or a single post concurrently.

    """

    def __init__(self, provider: PostDetailProvider = DefaultPostDetailProvider()):
        self.provider = provider
    
    async def _get_post_detail(self, token: str, semaphore: asyncio.Semaphore):
        async with ClientSession() as session:
            return await self.provider.get_detail(token, session, semaphore)
    
    def get_post_details(self, token: str | list, maximum_task: int = 5):
        """
        Retrieves the details of multiple or a single post concurrently.
        
        Args:
            token (str | list): The token(s) of the post(s). Can be a single token or a list of tokens.
            maximum_task (int): The maximum number of concurrent tasks. Defaults to 5.

        Returns:
            list: The details of the posts.

        """
        if isinstance(token, str):
            token = [token]

        loop = asyncio.get_event_loop()
        ads = []
        semaphore = asyncio.Semaphore(maximum_task)
        tasks = [self._get_post_detail(t, semaphore) for t in token]
        ads = loop.run_until_complete(asyncio.gather(*tasks))
        return ads



import os
import requests
from bs4 import BeautifulSoup
import json
import tempfile
import uuid
from loguru import logger
from .info import CITY_INFORMATION

class InitialDataScraper:
    URL="https://divar.ir/s/iran"
    def __init__(self, log=None):
        self.output_folder = os.path.join(tempfile.gettempdir(), f"divar_data_{uuid.uuid4().hex[:8]}")
        os.makedirs(self.output_folder, exist_ok=True)
        self.log = log or logger

    def send_request(self):
        try:
            response = requests.get(self.URL)
            response.raise_for_status()
            return response
        except requests.RequestException as e:
            self.log.error(f"Failed to send request. Error: {e}")
            return None

    def parse_html(self, response):
        if response and response.status_code == 200:
            soup = BeautifulSoup(response.text, 'html.parser')
            script_tag = soup.find('script', string=lambda text: text and 'window.__PRELOADED_STATE__' in text)
            return script_tag
        elif response:
            self.log.error(f"Failed to parse HTML. Status code: {response.status_code}")
            return None
        else:
            self.log.error("No response received for parsing HTML.")
            return None

    def extract(self, script_tag):
        if script_tag:
            raw_json = script_tag.string.partition('=')[-1].strip()
            raw_json = raw_json.split('};\n')[0] + '}'
            try:
                data = json.loads(raw_json)
                cities = data.get('multiCity', {}).get('data', {}).get('children', [])
                self.log.success("Data extracted and saved successfully.")
            except json.JSONDecodeError as e:
                self.log.error(f"Failed to decode JSON. Error: {e}")
                cities = CITY_INFORMATION
            return cities
        else:
            self.log.warning("Script tag not found.")

    def run(self):
        response = self.send_request()
        script_tag = self.parse_html(response)
        cities = self.extract(script_tag)
        
        return cities



import unittest
from unittest.mock import patch

from pydivar import PostDetailService

class TestPostDetailService(unittest.TestCase):
    
    @patch('pydivar.PostDetailService.get_post_details')
    def test_get_post_details(self, mock_get_post_details):
        """Test retrieving post details"""
        token = "some-token"
        
        details = PostDetailService().get_post_details(token)
        
        mock_get_post_details.assert_called_with(token)
        
    def test_get_post_details_default_params(self):
        """Test retrieving post details with default parameters"""
        details = PostDetailService().get_post_details(token="some-token")
        
        self.assertIsNotNone(details)
        
if __name__ == '__main__':
    unittest.main()


from setuptools import setup, find_packages

with open('requirements.txt') as f:
    requirements = f.read().splitlines()
    
with open('README.md') as f:
    long_description = f.read()

setup(
    name='pydivar',
    version='1.0.4',
    packages=find_packages(),
    install_requires=requirements,
    author='Ali Ardakani',
    author_email='aliardakani78@gmail.com',
    description='Python library for crawling and extracting data from Divar',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/ali-ardakani/pydivar.git',
    license='MIT',
)



import unittest
from unittest.mock import patch

from pydivar import AdFetcher

class TestAdFetcher(unittest.TestCase):

    @patch('pydivar.AdFetcher.get_ads')
    def test_get_ads(self, mock_get_ads):
        """Test retrieving ads with filters"""
        category = "light"
        sort = "sort_date" 
        cities = [16, 5]
        filters = {"body_status": ["some-scratches", "paintless-dent-removal"]}
        
        ads = AdFetcher.get_ads(
            category=category,
            sort=sort,
            cities=cities,
            filters=filters
        )
        
        mock_get_ads.assert_called_with(
            category=category,
            sort=sort, 
            cities=cities,
            filters=filters
        )

    def test_get_ads_default_params(self):
        """Test retrieving ads with default parameters"""
        ads = AdFetcher.get_ads(category="light")
        
        self.assertIsNotNone(ads)
        


if __name__ == '__main__':
    unittest.main()